@@ -1,6 +1,5 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 
-use warnings;
 use strict;
 use lib '.';
 use SOAP::Transport::HTTP;
