@@ -1,7 +1,6 @@
 package OpenFrame::Exception;
 
 use strict;
-use warnings::register;
 
 our @stack;
 
@@ -22,7 +21,7 @@ sub throw {
   my $this = shift;
   my $type = ref($this);
 
-  warnings::warn("[exception] exception of type $type thrown") if ( warnings::enabled() || $OpenFrame::DEBUG );
+  warn("[exception] exception of type $type thrown: $this->{message}") if $OpenFrame::DEBUG;
 
   push @OpenFrame::Exception::stack, $this;
 }
@@ -41,11 +40,11 @@ use base qw ( OpenFrame::Exception );
 
 1;
 
-=pod
+__END__
 
 =head1 NAME
 
-  OpenFrame::Exception - provides exception handling for OpenFrame
+OpenFrame::Exception - Provides exception handling for OpenFrame
 
 =head1 SYNOPSIS
 
@@ -56,17 +55,24 @@ use base qw ( OpenFrame::Exception );
 
 =head1 DESCRIPTION
 
-As perl doesn't have an exception mechanism of its own beyond $@, and as $@ is used frequently
-by OpenFrame, yet another exception mechanism is desirable within OpenFrame.  There are three
-defined exception classes in OpenFrame: I<OpenFrame::Exception::Perl>, I<OpenFrame::Exception::Application>,
-and I<OpenFrame::Exception::Slot>.
+As Perl does not have an exception mechanism of its own beyond $@, and
+as $@ is used frequently by OpenFrame, yet another exception mechanism
+is desirable within OpenFrame.  There are three defined exception
+classes in OpenFrame: I<OpenFrame::Exception::Perl>,
+I<OpenFrame::Exception::Application>, and
+I<OpenFrame::Exception::Slot>.
 
 =head1 AUTHOR
 
-James A. Duncan
+James A. Duncan <jduncan@fotango.com>
 
 =head1 BUGS
 
 You can only write a slot to deal with one of any given exception classes.
 
-=cut
+=head1 COPYRIGHT
+
+Copyright (C) 2001, Fotango Ltd.
+
+This module is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
